@@ -3,33 +3,33 @@
 import os
 import re
 import tempfile
-import logging
 
-from . import log
+from .log import logger
 
-version = "2.0.3" 
+version = "2.1.2"
 
-logger = logging.getLogger(__name__)
-logger.setLevel(logging.INFO)
+TEMP_DIR = tempfile.gettempdir()  # str type
 
-TEMP_DIR = tempfile.gettempdir()   # str type
 
 def find_tempfile(dir):
     for _, _, files in os.walk(dir):
         for f in files:
-            match = re.search(r'^fake_useragent_', f)
+            match = re.search(r"^fake_useragent_", f)
             if match:
                 logger.debug(f"{f} is found.")
-                return os.path.join(dir, f)    # str type
+                return os.path.join(dir, f)  # str type
 
     logger.debug("No cache is found.")
-    return "" 
+    return ""
 
-TEMP_FILE = find_tempfile(TEMP_DIR)
 
-DB = os.path.join(TEMP_DIR, "fake_useragent_{version}.json".format(version=version)) # str type
+DB = os.path.join(
+    TEMP_DIR, "fake_useragent_{version}.json".format(version=version)
+)  # str type
 
-BROWSER_BASE_PAGE = "http://useragentstring.com/pages/useragentstring.php?name={browser}"
+BROWSER_BASE_PAGE = (
+    "http://useragentstring.com/pages/useragentstring.php?name={browser}"
+)
 
 BROWSERS = {
     "chrome": 80.7,
@@ -50,5 +50,3 @@ SHORTCUTS = {
 BROWSERS_COUNT_LIMIT = 50
 
 HTTP_TIMEOUT = 10
-
-
